##  Benefits
The transformations explorer enables:
  * Effective oversight of transformations, dependencies, and upcoming go-lives
  * Filtering transformations by scope to see only relevant items, for example, transformation items that are ready for execution
  * Inline editing for quick updates without navigation
  * Bulk actions to edit and execute multiple transformations at once
